import { MergeRequestNoteSchema } from "@gitbeaker/rest"

import GitlabBaseService from "./base"

class Notes extends GitlabBaseService {
  /**
   * 创建一个新的合并请求备注
   * @param {string} body - 备注内容
   * @returns {Promise<MergeRequestNoteSchema>} - 返回包含新创建备注的Promise
   */
  async create(body: string): Promise<MergeRequestNoteSchema> {
    const URL = `/projects/${this.project_id}/merge_requests/${this.merge_request_iid}/notes`
    return this.errorWarp<MergeRequestNoteSchema>(
      () => this.post(URL, { body }),
      null
    )
  }

  /**
   * 修改一个现有的合并请求备注
   * @param {number} note_id - 备注ID
   * @param {string} body - 新的备注内容
   * @returns {Promise<MergeRequestNoteSchema>} - 返回包含修改后备注的Promise
   */
  async modify(note_id: number, body: string): Promise<MergeRequestNoteSchema> {
    const URL = `/projects/${this.project_id}/merge_requests/${this.merge_request_iid}/notes/${note_id}`
    return this.errorWarp<MergeRequestNoteSchema>(
      () => this.put(URL, { body }),
      null
    )
  }
}

export default Notes
